LIMConditional <-
function(x,z,IM,LIM,nameNames=TRUE){
	# Computes the t-test p-value for 2 measured SNPs x and z, given that x had a non-zero latent interaction coefficient with LIMEst
	# Assumes b*x*z = b_latent * x * z_latent + e
	# Arguments:
	#	x : measured SNP encoded as {0,1,2}
	#	z : measured SNP encoded as {0,1,2}
	#	IM : interaction model with x and z - output from IMEst
	#	LIM : latent interaction model with x - output from LIMEst
	#	nameNames : optional naming for the entries of the output vector
	# Value:
	#	A vector of numerical values:
	#		b_latent
	#		1-coefficient of determination between IM and LIM
	#		estimated LD from LIM
	#		MAF of SNP x
	#		MAF of SNP z = 0.5
	#		conditional standard error of the estimate b
	#		sample size
	#		conditional p-value for the estimate b using the t-test
	#		index of SNP x
	#		index of SNP z
	
	ypred<-IM[1]*x*z;
	nas<-!is.na(ypred);
	U<-x[nas];
	V<-ypred[nas];
	
	## compute moment
	m1<-mean((U-mean(U))*(V-mean(V)));
	m2<-mean((U-mean(U))^2*(V-mean(V)));
	
	## get sample size
	n<-length(V);
	
	## compute MAF of observed SNP
	q<-mean(U)/2;

	## fix MAF of latent SNP to 0.5
	p<-.5;
	
	D<-LIM[3];
	b<-(D*m1 + D*m2 + 2*m1*p*q + 2*m2*p*q - 2*D*m2*q**2 - 2*m1*p*q**2 - 6*m2*p*q**2 + 4*m2*p*q**3)/(4.*(D**2 + 4*D*p*q - 2*D**2*q**2 - 8*D*p*q**2 + 4*p**2*q**2 - 16*p**2*q**3 + 2*D**2*q**4 + 12*D*p*q**4 + 28*p**2*q**4 - 8*D*p*q**5 - 24*p**2*q**5 + 8*p**2*q**6));
	## compute noise variance	
	sigma<-abs(var(V)-b^2*(((4-8*p)*q+4*p+2)*D+(4*p-12*p^2)*q^2+(4*p^2+4*p)*q))+IM[2];
	
	## compute predictor variance
	VX<-(((4-8*p)*q+4*p+2)*D+(4*p-12*p^2)*q^2+(4*p^2+4*p)*q);
	
	## compute predictor expected value and predictor x noise variance for robust standard error
	EX<-2*D+4*p*q;
	VeX<-sigma*(VX+EX^2);
	
	## compute White's robust standard error on interaction coefficient estimate
	varblIb<-VeX/VX^2;
	varbl<-LIM[6]^2*LIM[7];
	varb<-IM[6]^2*IM[7];
	
	rho<-varblIb/varbl;
	if(is.na(rho)){rho<-1};
	if(rho>1){rho<-1};
	
	varbIbl<-rho*varb;
	ser<-sqrt(varbIbl/n);
	## perfrom t-test comparing interaction coefficient to zero
	pValue<-2*pt(abs(IM[1])/ser,n-1,lower.tail=F);
	
	out<-c(b,
		 rho,
		 D,
		 q,
		 p,
		 ser,
		 n,
		 pValue,
		 IM[9],
		 IM[10]);
	if(nameNames){
		names(out)<-c("interaction",
		 	"1-corr^2",
		 	"LD",
		 	"MAF1",
		 	"MAF2",
		 	"ser",
		 	"sample_size",
		 	"pValue",
		 	"SNP1Index",
		 	"SNP2Index");
	}
	return(out);
}
