LIMEst <-
function(x,y,xIndex=NA,nameNames=TRUE){
	# Latent multiplicative interaction phenotype model estimation y=b*x*z+e
	# with latent SNP z
	# Arguments:
	#	x : measured SNP encoded as {0,1,2}
	#	y : measured continuous phenotype 
	#	xIndex : optional index for the SNP x in the dataset
	#	nameNames : optional naming for the entries of the output vector
	# Value:
	#	A vector of numerical values:
	#		regression (interaction) coefficient b
	#		variance of the noise e
	#		estimated LD between the 2 SNPs
	#		MAF of SNP x
	#		MAF of SNP z = 0.5
	#		standard error of the estimate b
	#		sample size
	#		p-value for the estimate using the t-test
	#		index of SNP x as given by xIndex
	#		index of SNP z = NA
	
	nas<-!is.na(x);
	U<-x[nas];
	V<-y[nas];
	
	## compute the sample moments of the distribution of [U,V]
	S<-moments(U,V);
	K<-S[1,1];
	L<-S[2,1];
	
	## compute the weight matrix as the covariance matrix of S
	W<-momentcov(U,V,S);
	M<-W[1,1];
	N<-W[2,2];
	
	## get sample size
	n<-length(V);
	
	## compute MAF of observed SNP
	q<-mean(U)/2;

	## fix MAF of latent SNP to 0.5
	p<-.5;
	
	## estimate parameters using the unconstrained optimization solution
	rawest<-sol(q,K,L,M,N);
	
	## check if solution is feasible
	if(rawest[2]>(1-p)*q||rawest[2]<(-p*q)){
		## if unconstrained solution not feasible, compute the two KKT solutions
		rawest<-rbind(solpos(q,K,L,M,N),
					  solneg(q,K,L,M,N));
		## evaluate cost functional at solutions
		mini<-c(costEval(K,L,M,N,p,q,rawest[1,2],rawest[1,3]), costEval(K,L,M,N,p,q,rawest[2,2],rawest[2,3]));
		
		## order KKT solutions increasingly
		idx<-order(mini,decreasing=F)[1];
		
		## and choose the parameter estimates from the constrained optimization problem
		rawest<-rawest[idx,];
	}
	b<-rawest[3];
	D<-rawest[2];
		
	## compute noise variance	
	sigma<-abs(var(V)-b^2*(((4-8*p)*q+4*p+2)*D+(4*p-12*p^2)*q^2+(4*p^2+4*p)*q));
	
	## compute predictor variance
	VX<-(((4-8*p)*q+4*p+2)*D+(4*p-12*p^2)*q^2+(4*p^2+4*p)*q);
	
	## compute predictor expected value and predictor x noise variance for robust standard error
	EX<-2*D+4*p*q;
	VeX<-sigma*(VX+EX^2);
	
	## compute White's robust standard error on interaction coefficient estimate
	ser<-sqrt(1/n*VeX)/VX;
	
	## perfrom t-test comparing interaction coefficient to zero
	pValue<-2*pt(abs(b)/ser,n-1,lower.tail=F);
	
	out<-c(b,
		 sigma,
		 D,
		 q,
		 p,
		 ser,
		 n,
		 pValue,
		 xIndex,
		 NA);
	if(nameNames){
		names(out)<-c("interaction",
		 	"sigma",
		 	"LD",
		 	"MAF1",
		 	"MAF2",
		 	"ser",
		 	"sample_size",
		 	"pValue",
		 	"SNP1Index",
		 	"SNP2Index");
	}
	return(out);
}
